nodegroup

package
v0.0.0-...-1f78e34 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2023 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Labels

type Labels struct {
}

Labels The Kubernetes labels to be applied to the nodes in the node group when they are created.

func (*Labels) MarshalJSON

func (strct *Labels) MarshalJSON() ([]byte, error)

func (*Labels) UnmarshalJSON

func (strct *Labels) UnmarshalJSON(b []byte) error

type LaunchTemplateSpecification

type LaunchTemplateSpecification struct {
	Id      string `json:"Id,omitempty"`
	Name    string `json:"Name,omitempty"`
	Version string `json:"Version,omitempty"`
}

LaunchTemplateSpecification An object representing a launch template specification for AWS EKS Nodegroup.

func (*LaunchTemplateSpecification) MarshalJSON

func (strct *LaunchTemplateSpecification) MarshalJSON() ([]byte, error)

func (*LaunchTemplateSpecification) UnmarshalJSON

func (strct *LaunchTemplateSpecification) UnmarshalJSON(b []byte) error

type RemoteAccess

type RemoteAccess struct {
	Ec2SshKey            string   `json:"Ec2SshKey"`
	SourceSecurityGroups []string `json:"SourceSecurityGroups,omitempty"`
}

RemoteAccess An object representing a remote access configuration specification for AWS EKS Nodegroup.

func (*RemoteAccess) MarshalJSON

func (strct *RemoteAccess) MarshalJSON() ([]byte, error)

func (*RemoteAccess) UnmarshalJSON

func (strct *RemoteAccess) UnmarshalJSON(b []byte) error

type Resource

type Resource struct {

	// The AMI type for your node group.
	AmiType string `json:"AmiType,omitempty"`
	Arn     string `json:"Arn,omitempty"`

	// The capacity type of your managed node group.
	CapacityType string `json:"CapacityType,omitempty"`

	// Name of the cluster to create the node group in.
	ClusterName string `json:"ClusterName"`

	// The root device disk size (in GiB) for your node group instances.
	DiskSize int `json:"DiskSize,omitempty"`

	// Force the update if the existing node group's pods are unable to be drained due to a pod disruption budget issue.
	ForceUpdateEnabled bool   `json:"ForceUpdateEnabled,omitempty"`
	Id                 string `json:"Id,omitempty"`

	// Specify the instance types for a node group.
	InstanceTypes []string `json:"InstanceTypes,omitempty"`

	// The Kubernetes labels to be applied to the nodes in the node group when they are created.
	Labels *Labels `json:"Labels,omitempty"`

	// An object representing a node group's launch template specification.
	LaunchTemplate *LaunchTemplateSpecification `json:"LaunchTemplate,omitempty"`

	// The Amazon Resource Name (ARN) of the IAM role to associate with your node group.
	NodeRole string `json:"NodeRole"`

	// The unique name to give your node group.
	NodegroupName string `json:"NodegroupName,omitempty"`

	// The AMI version of the Amazon EKS-optimized AMI to use with your node group.
	ReleaseVersion string `json:"ReleaseVersion,omitempty"`

	// The remote access (SSH) configuration to use with your node group.
	RemoteAccess *RemoteAccess `json:"RemoteAccess,omitempty"`

	// The scaling configuration details for the Auto Scaling group that is created for your node group.
	ScalingConfig *ScalingConfig `json:"ScalingConfig,omitempty"`

	// The subnets to use for the Auto Scaling group that is created for your node group.
	Subnets []string `json:"Subnets"`

	// The metadata, as key-value pairs, to apply to the node group to assist with categorization and organization. Follows same schema as Labels for consistency.
	Tags *Tags `json:"Tags,omitempty"`

	// The Kubernetes taints to be applied to the nodes in the node group when they are created.
	Taints []*Taint `json:"Taints,omitempty"`

	// The node group update configuration.
	UpdateConfig *UpdateConfig `json:"UpdateConfig,omitempty"`

	// The Kubernetes version to use for your managed nodes.
	Version string `json:"Version,omitempty"`
}

Resource Resource schema for AWS::EKS::Nodegroup

func (*Resource) MarshalJSON

func (strct *Resource) MarshalJSON() ([]byte, error)

func (*Resource) UnmarshalJSON

func (strct *Resource) UnmarshalJSON(b []byte) error

type ScalingConfig

type ScalingConfig struct {
	DesiredSize int `json:"DesiredSize,omitempty"`
	MaxSize     int `json:"MaxSize,omitempty"`
	MinSize     int `json:"MinSize,omitempty"`
}

ScalingConfig An object representing a auto scaling group specification for AWS EKS Nodegroup.

func (*ScalingConfig) MarshalJSON

func (strct *ScalingConfig) MarshalJSON() ([]byte, error)

func (*ScalingConfig) UnmarshalJSON

func (strct *ScalingConfig) UnmarshalJSON(b []byte) error

type Tags

type Tags struct {
}

Tags The metadata, as key-value pairs, to apply to the node group to assist with categorization and organization. Follows same schema as Labels for consistency.

func (*Tags) MarshalJSON

func (strct *Tags) MarshalJSON() ([]byte, error)

func (*Tags) UnmarshalJSON

func (strct *Tags) UnmarshalJSON(b []byte) error

type Taint

type Taint struct {
	Effect string `json:"Effect,omitempty"`
	Key    string `json:"Key,omitempty"`
	Value  string `json:"Value,omitempty"`
}

Taint An object representing a Taint specification for AWS EKS Nodegroup.

func (*Taint) MarshalJSON

func (strct *Taint) MarshalJSON() ([]byte, error)

func (*Taint) UnmarshalJSON

func (strct *Taint) UnmarshalJSON(b []byte) error

type UpdateConfig

type UpdateConfig struct {

	// The maximum number of nodes unavailable at once during a version update. Nodes will be updated in parallel. This value or maxUnavailablePercentage is required to have a value.The maximum number is 100.
	MaxUnavailable float64 `json:"MaxUnavailable,omitempty"`

	// The maximum percentage of nodes unavailable during a version update. This percentage of nodes will be updated in parallel, up to 100 nodes at once. This value or maxUnavailable is required to have a value.
	MaxUnavailablePercentage float64 `json:"MaxUnavailablePercentage,omitempty"`
}

UpdateConfig The node group update configuration.

func (*UpdateConfig) MarshalJSON

func (strct *UpdateConfig) MarshalJSON() ([]byte, error)

func (*UpdateConfig) UnmarshalJSON

func (strct *UpdateConfig) UnmarshalJSON(b []byte) error

Jump to